<h1 align="center" id="title">AutoQuiz</h1>

<p id="description">A simple tool for you as student to create quizzes based on your own study notes.</p>

<p align="center"><img src="https://img.shields.io/badge/AQ-AutoQuiz-light%20blue" alt="shields"></p>

  
  
<h2>🧐 Features</h2>

Here're some of the project's best features:

*   Select note format

<h2>🛠️ Installation Steps:</h2>

<p>1. Get you into PyPI</p>

<h2>🍰 Contribution Guidelines:</h2>

Please use Conventional Commits standard. This's using CI hence all no-working code will be rejected automatically.

  
  
<h2>💻 Built with</h2>

Technologies used in the project:

*   Poetry
*   Python
*   Behave

<h2>🛡️ License:</h2>

This project is licensed under the DWYW-BDSM: Do whatever you want but don't sue me.
